@@ -148,7 +148,8 @@ class Confluence(AtlassianRestAPI):
             return self.get(url, params=params)
         else:
             try:
-                return (self.get(url, params=params) or {}).get('results')[0]
+                response = (self.get(url, params=params) or {}).get('results')
+                return response[0] if response else None
             except (IndexError, TypeError) as e:
                 log.error("Can't find '{title}' page on the {url}!".format(title=title, url=self.url))
                 log.debug(e)
@@ -732,6 +733,13 @@ class Confluence(AtlassianRestAPI):
         :param title: Title to compare
         :return: True if the same
         """
+        confluence_content = self.get_page_by_id(page_id)
+        if title:
+            current_title = confluence_content.get('title', None)
+            if title != current_title:
+                log.info('Title of {page_id} is different'.format(page_id=page_id))
+                return False
+
         if self.advanced_mode:
             confluence_content = (((self.get_page_by_id(page_id, expand='body.storage').json() or {})
                                    .get('body') or {})
@@ -741,12 +749,6 @@ class Confluence(AtlassianRestAPI):
                                    .get('body') or {})
                                   .get('storage') or {})
 
-        if title:
-            current_title = confluence_content.get('title', None)
-            if title != current_title:
-                log.info('Title of {page_id} is different'.format(page_id=page_id))
-                return False
-
         confluence_body_content = confluence_content.get('value')
 
         if confluence_body_content:
@@ -764,14 +766,15 @@ class Confluence(AtlassianRestAPI):
             return False
 
     def update_existing_page(self, page_id, title, body, type='page', representation='storage',
-                             minor_edit=False):
+                             minor_edit=False, version_comment=None):
         """Duplicate update_page. Left for the people who used it before. Use update_page instead"""
         return self.update_page(page_id=page_id, title=title, body=body, parent_id=None, type=type,
                                 representation=representation,
-                                minor_edit=minor_edit)
+                                minor_edit=minor_edit,
+                                version_comment=version_comment)
 
     def update_page(self, page_id, title, body, parent_id=None, type='page', representation='storage',
-                    minor_edit=False):
+                    minor_edit=False, version_comment=None):
         """
         Update page if already exist
         :param page_id:
@@ -782,6 +785,7 @@ class Confluence(AtlassianRestAPI):
         :param representation: OPTIONAL: either Confluence 'storage' or 'wiki' markup format
         :param minor_edit: Indicates whether to notify watchers about changes.
             If False then notifications will be sent.
+        :param version_comment: Version comment
         :return:
         """
         log.info('Updating {type} "{title}"'.format(title=title, type=type))
@@ -810,12 +814,14 @@ class Confluence(AtlassianRestAPI):
 
             if parent_id:
                 data['ancestors'] = [{'type': 'page', 'id': parent_id}]
+            if version_comment:
+                data['version']['message'] = version_comment
 
             return self.put('rest/api/content/{0}'.format(page_id), data=data)
 
     def _insert_to_existing_page(self, page_id, title, insert_body, parent_id=None, type='page',
                                  representation='storage',
-                                 minor_edit=False, top_of_page=False):
+                                 minor_edit=False, version_comment=None, top_of_page=False):
         """
         Insert body to a page if already exist
         :param parent_id:
@@ -851,6 +857,8 @@ class Confluence(AtlassianRestAPI):
 
             if parent_id:
                 data['ancestors'] = [{'type': 'page', 'id': parent_id}]
+            if version_comment:
+                data['version']['message'] = version_comment
 
             return self.put('rest/api/content/{0}'.format(page_id), data=data)
 
@@ -894,7 +902,8 @@ class Confluence(AtlassianRestAPI):
                                              representation=representation,
                                              minor_edit=minor_edit, top_of_page=True)
 
-    def update_or_create(self, parent_id, title, body, representation='storage', minor_edit=False):
+    def update_or_create(self, parent_id, title, body, representation='storage', minor_edit=False,
+                         version_comment=None):
         """
         Update page or create a page if it is not exists
         :param parent_id:
@@ -902,6 +911,7 @@ class Confluence(AtlassianRestAPI):
         :param body:
         :param representation: OPTIONAL: either Confluence 'storage' or 'wiki' markup format
         :param minor_edit: Update page without notification
+        :param version_comment: Version comment
         :return:
         """
         space = self.get_page_space(parent_id)
@@ -910,7 +920,8 @@ class Confluence(AtlassianRestAPI):
             page_id = self.get_page_id(space, title)
             parent_id = self.get_parent_content_id(page_id)
             result = self.update_page(parent_id=parent_id, page_id=page_id, title=title, body=body,
-                                      representation=representation, minor_edit=minor_edit)
+                                      representation=representation, minor_edit=minor_edit,
+                                      version_comment=version_comment)
         else:
             result = self.create_page(space=space, parent_id=parent_id, title=title, body=body,
                                       representation=representation)
@@ -1256,13 +1267,11 @@ class Confluence(AtlassianRestAPI):
         files = {
             'plugin': open(plugin_path, 'rb')
         }
-        headers = {
-            'X-Atlassian-Token': 'nocheck'
-        }
-        upm_token = self.request(method='GET', path='rest/plugins/1.0/', headers=headers, trailing=True).headers[
-            'upm-token']
+        upm_token = \
+            self.request(method='GET', path='rest/plugins/1.0/', headers=self.no_check_headers, trailing=True).headers[
+                'upm-token']
         url = 'rest/plugins/1.0/?token={upm_token}'.format(upm_token=upm_token)
-        return self.post(url, files=files, headers=headers)
+        return self.post(url, files=files, headers=self.no_check_headers)
 
     def delete_plugin(self, plugin_key):
         """
